@@ -1,7 +1,7 @@
 #[cfg(feature = "sled-storage")]
 use {
     futures::executor::block_on,
-    gluesql::{execute, parse, translate, Glue, SledStorage},
+    gluesql::prelude::{execute, parse, translate, Glue, SledStorage},
 };
 
 #[cfg(feature = "sled-storage")]
@@ -31,14 +31,33 @@ fn mutable_api() {
     let storage = SledStorage::new("data/mutable-api").unwrap();
     let mut glue = Glue::new(storage);
 
-    let sqls = "
-        CREATE TABLE Glue (id INTEGER);
-        INSERT INTO Glue VALUES (100);
-        INSERT INTO Glue VALUES (200);
-        DROP TABLE Glue;
-    ";
+    let sqls = [
+        "CREATE TABLE Glue (id INTEGER);",
+        "INSERT INTO Glue VALUES (100);",
+        "INSERT INTO Glue VALUES (200);",
+        "DROP TABLE Glue;",
+    ];
 
-    glue.execute(sqls).unwrap();
+    for sql in sqls {
+        glue.execute(sql).unwrap();
+    }
+}
+
+#[cfg(feature = "sled-storage")]
+async fn async_mutable_api() {
+    let storage = SledStorage::new("data/async-mutable-api").unwrap();
+    let mut glue = Glue::new(storage);
+
+    let sqls = [
+        "CREATE TABLE Glue (id INTEGER);",
+        "INSERT INTO Glue VALUES (100);",
+        "INSERT INTO Glue VALUES (200);",
+        "DROP TABLE Glue;",
+    ];
+
+    for sql in sqls {
+        glue.execute_async(sql).await.unwrap();
+    }
 }
 
 fn main() {
@@ -46,5 +65,6 @@ fn main() {
     {
         mutable_api();
         immutable_api();
+        block_on(async_mutable_api());
     }
 }
