@@ -1,8 +1,14 @@
 use {
-    super::{Value, ValueError},
-    crate::result::{Error, Result},
-    chrono::{NaiveDate, NaiveDateTime},
-    std::convert::TryInto,
+    super::{
+        date::{parse_date, parse_time, parse_timestamp},
+        Value, ValueError,
+    },
+    crate::{
+        data::Interval,
+        result::{Error, Result},
+    },
+    chrono::{NaiveDate, NaiveDateTime, NaiveTime},
+    uuid::Uuid,
 };
 
 impl From<&Value> for String {
@@ -16,6 +22,9 @@ impl From<&Value> for String {
             Value::Timestamp(value) => value.to_string(),
             Value::Time(value) => value.to_string(),
             Value::Interval(value) => String::from(value),
+            Value::Uuid(value) => Uuid::from_u128(*value).to_string(),
+            Value::Map(_) => "[MAP]".to_owned(),
+            Value::List(_) => "[LIST]".to_owned(),
             Value::Null => String::from("NULL"),
         }
     }
@@ -59,6 +68,9 @@ impl TryInto<bool> for &Value {
             | Value::Timestamp(_)
             | Value::Time(_)
             | Value::Interval(_)
+            | Value::Uuid(_)
+            | Value::Map(_)
+            | Value::List(_)
             | Value::Null => return Err(ValueError::ImpossibleCast.into()),
         })
     }
@@ -93,6 +105,9 @@ impl TryInto<i64> for &Value {
             | Value::Timestamp(_)
             | Value::Time(_)
             | Value::Interval(_)
+            | Value::Uuid(_)
+            | Value::Map(_)
+            | Value::List(_)
             | Value::Null => return Err(ValueError::ImpossibleCast.into()),
         })
     }
@@ -127,6 +142,9 @@ impl TryInto<f64> for &Value {
             | Value::Timestamp(_)
             | Value::Time(_)
             | Value::Interval(_)
+            | Value::Uuid(_)
+            | Value::Map(_)
+            | Value::List(_)
             | Value::Null => return Err(ValueError::ImpossibleCast.into()),
         })
     }
@@ -139,6 +157,19 @@ impl TryInto<NaiveDate> for &Value {
         Ok(match self {
             Value::Date(value) => *value,
             Value::Timestamp(value) => value.date(),
+            Value::Str(value) => parse_date(value).ok_or(ValueError::ImpossibleCast)?,
+            _ => return Err(ValueError::ImpossibleCast.into()),
+        })
+    }
+}
+
+impl TryInto<NaiveTime> for &Value {
+    type Error = Error;
+
+    fn try_into(self) -> Result<NaiveTime> {
+        Ok(match self {
+            Value::Time(value) => *value,
+            Value::Str(value) => parse_time(value).ok_or(ValueError::ImpossibleCast)?,
             _ => return Err(ValueError::ImpossibleCast.into()),
         })
     }
@@ -150,8 +181,31 @@ impl TryInto<NaiveDateTime> for &Value {
     fn try_into(self) -> Result<NaiveDateTime> {
         Ok(match self {
             Value::Date(value) => value.and_hms(0, 0, 0),
+            Value::Str(value) => parse_timestamp(value).ok_or(ValueError::ImpossibleCast)?,
             Value::Timestamp(value) => *value,
             _ => return Err(ValueError::ImpossibleCast.into()),
         })
     }
 }
+
+impl TryInto<Interval> for &Value {
+    type Error = Error;
+
+    fn try_into(self) -> Result<Interval> {
+        match self {
+            Value::Str(value) => Interval::try_from(value.as_str()),
+            _ => Err(ValueError::ImpossibleCast.into()),
+        }
+    }
+}
+
+impl TryInto<u128> for &Value {
+    type Error = Error;
+
+    fn try_into(self) -> Result<u128> {
+        match self {
+            Value::Uuid(value) => Ok(*value),
+            _ => Err(ValueError::ImpossibleCast.into()),
+        }
+    }
+}
