@@ -4,7 +4,6 @@ use {
         executor::UniqueKey,
         result::{Error, Result},
     },
-    std::convert::TryInto,
 };
 
 impl TryInto<Option<UniqueKey>> for &Value {
@@ -13,6 +12,10 @@ impl TryInto<Option<UniqueKey>> for &Value {
     fn try_into(self) -> Result<Option<UniqueKey>> {
         use Value::*;
 
+        let conflict = |data_type: &str| {
+            Err(ValueError::ConflictDataTypeOnUniqueConstraint(data_type.to_owned()).into())
+        };
+
         let unique_key = match self {
             Bool(v) => Some(UniqueKey::Bool(*v)),
             I64(v) => Some(UniqueKey::I64(*v)),
@@ -21,10 +24,11 @@ impl TryInto<Option<UniqueKey>> for &Value {
             Timestamp(v) => Some(UniqueKey::Timestamp(*v)),
             Time(v) => Some(UniqueKey::Time(*v)),
             Interval(v) => Some(UniqueKey::Interval(*v)),
+            Uuid(v) => Some(UniqueKey::Uuid(*v)),
             Null => None,
-            F64(_) => {
-                return Err(ValueError::ConflictOnFloatWithUniqueConstraint.into());
-            }
+            F64(_) => return conflict("FLOAT"),
+            Map(_) => return conflict("MAP"),
+            List(_) => return conflict("LIST"),
         };
 
         Ok(unique_key)
