@@ -28,6 +28,9 @@ pub enum EvaluateError {
     #[error("function requires float value: {0}")]
     FunctionRequiresFloatValue(String),
 
+    #[error("function requires map value: {0}")]
+    FunctionRequiresMapValue(String),
+
     #[error("value not found: {0}")]
     ValueNotFound(String),
 
@@ -49,6 +52,9 @@ pub enum EvaluateError {
     #[error("unreachable empty aggregate value: {0:?}")]
     UnreachableEmptyAggregateValue(Aggregate),
 
-    #[error("divisor should not be zero")]
-    InvalidDivisorZero,
+    #[error("the divisor should not be zero")]
+    DivisorShouldNotBeZero,
+
+    #[error("negative substring length not allowed")]
+    NegativeSubstrLenNotAllowed,
 }
