@@ -7,10 +7,10 @@ use {
     crate::{
         ast::IndexOperator,
         data::Row,
+        prelude::Value,
         result::{Error, Result},
-        store::{Index, RowIter},
+        store::{Index, IndexError, RowIter},
         utils::Vector,
-        IndexError, Value,
     },
     async_trait::async_trait,
     iter_enum::{DoubleEndedIterator, Iterator},
@@ -61,7 +61,7 @@ impl Index<IVec> for SledStorage {
                     };
                     let lower = || build_index_key_prefix(table_name, index_name);
                     let upper = || incr(build_index_key_prefix(table_name, index_name));
-                    let key = build_index_key(table_name, index_name, value);
+                    let key = build_index_key(table_name, index_name, value)?;
 
                     match op {
                         IndexOperator::Eq => match self.tree.get(&key).transpose() {
