@@ -1,8 +1,16 @@
 use {
     super::{err_into, fetch_schema, key, Snapshot},
     crate::{
-        ast::Expr, evaluate_stateless, utils::Vector, Error, IndexError, Row, Schema, SchemaIndex,
-        Value,
+        ast::Expr,
+        data::{
+            schema::{Schema, SchemaIndex},
+            Row,
+        },
+        executor::evaluate_stateless,
+        prelude::Value,
+        result::{Error, Result},
+        store::IndexError,
+        utils::Vector,
     },
     sled::{
         transaction::{
@@ -10,7 +18,7 @@ use {
         },
         IVec,
     },
-    std::{borrow::Cow, convert::TryInto},
+    std::borrow::Cow,
 };
 
 pub struct IndexSync<'a> {
@@ -250,16 +258,16 @@ fn evaluate_index_key(
         .try_into()
         .map_err(ConflictableTransactionError::Abort)?;
 
-    Ok(build_index_key(table_name, index_name, value))
+    build_index_key(table_name, index_name, value).map_err(ConflictableTransactionError::Abort)
 }
 
 pub fn build_index_key_prefix(table_name: &str, index_name: &str) -> Vec<u8> {
     format!("index/{}/{}/", table_name, index_name).into_bytes()
 }
 
-pub fn build_index_key(table_name: &str, index_name: &str, value: Value) -> Vec<u8> {
-    build_index_key_prefix(table_name, index_name)
+pub fn build_index_key(table_name: &str, index_name: &str, value: Value) -> Result<Vec<u8>> {
+    Ok(build_index_key_prefix(table_name, index_name)
         .into_iter()
-        .chain(value.to_be_bytes().into_iter())
-        .collect::<Vec<_>>()
+        .chain(value.to_cmp_be_bytes()?)
+        .collect::<Vec<_>>())
 }
