@@ -15,8 +15,8 @@ use {
     self::snapshot::Snapshot,
     crate::{
         data::Schema,
+        result::{Error, Result},
         store::{GStore, GStoreMut},
-        Error, Result,
     },
     error::{err_into, tx_err_into},
     sled::{
@@ -26,7 +26,6 @@ use {
         },
         Config, Db, IVec,
     },
-    std::convert::TryFrom,
 };
 
 /// default transaction timeout : 1 hour
