@@ -1,6 +1,11 @@
 use crate::*;
 
 test_case!(create_table, async move {
+    use {
+        executor::{AlterError, EvaluateError},
+        prelude::Payload,
+        translate::TranslateError,
+    };
     let test_cases = vec![
         (
             r#"
@@ -44,10 +49,18 @@ test_case!(create_table, async move {
             "CREATE TABLE Gluery (id SOMEWHAT);",
             Err(TranslateError::UnsupportedDataType("SOMEWHAT".to_owned()).into()),
         ),
+        (
+            "CREATE TABLE Gluery (id BYTEA);",
+            Err(TranslateError::UnsupportedDataType("BYTEA".to_owned()).into()),
+        ),
         (
             "CREATE TABLE Gluery (id INTEGER CHECK (true));",
             Err(TranslateError::UnsupportedColumnOption("CHECK (true)".to_owned()).into()),
         ),
+        (
+            "CREATE TABLE Glue (id INTEGER PRIMARY KEY)",
+            Err(TranslateError::UnsupportedColumnOption(("PRIMARY KEY").to_owned()).into()),
+        ),
         (
             r#"
         CREATE TABLE CreateTable3 (
