@@ -1,5 +1,8 @@
 pub mod date;
 pub mod interval;
+pub mod list;
+pub mod map;
 pub mod sql_types;
 pub mod time;
 pub mod timestamp;
+pub mod uuid;
