@@ -1,6 +1,12 @@
-use {crate::*, std::borrow::Cow};
+use crate::*;
 
 test_case!(filter, async move {
+    use {
+        bigdecimal::BigDecimal,
+        data::*,
+        std::{borrow::Cow, str::FromStr},
+    };
+
     let create_sqls = [
         "
         CREATE TABLE Boss (
@@ -80,8 +86,15 @@ test_case!(filter, async move {
         (2, "SELECT name FROM Boss WHERE name LIKE '%r%'"),
         (2, "SELECT name FROM Boss WHERE name LIKE '%a'"),
         (5, "SELECT name FROM Boss WHERE name LIKE '%%'"),
+        (0, "SELECT name FROM Boss WHERE name LIKE 'g%'"),
+        (2, "SELECT name FROM Boss WHERE name ILIKE '_A%'"),
+        (2, "SELECT name FROM Boss WHERE name ILIKE 'g%'"),
+        (5, "SELECT name FROM Boss WHERE name ILIKE '%%'"),
         (1, "SELECT name FROM Boss WHERE name NOT LIKE '%a%'"),
+        (1, "SELECT name FROM Boss WHERE name NOT ILIKE '%A%'"),
         (5, "SELECT name FROM Boss WHERE 'ABC' LIKE '_B_'"),
+        (5, "SELECT name FROM Boss WHERE 'abc' ILIKE '_B_'"),
+        (5, "SELECT name FROM Boss WHERE 'ABC' ILIKE '_B_'"),
     ];
 
     for (num, sql) in select_sqls.iter() {
@@ -119,7 +132,10 @@ test_case!(filter, async move {
         (
             LiteralError::LikeOnNonString(
                 format!("{:?}", Literal::Text(Cow::Owned("ABC".to_string()))),
-                format!("{:?}", Literal::Number(Cow::Owned("10".to_string()))),
+                format!(
+                    "{:?}",
+                    Literal::Number(Cow::Owned(BigDecimal::from_str("10").unwrap()))
+                ),
             )
             .into(),
             "SELECT name FROM Boss WHERE 'ABC' LIKE 10",
@@ -128,6 +144,10 @@ test_case!(filter, async move {
             ValueError::LikeOnNonString(Value::Str("Amelia".to_string()), Value::I64(10)).into(),
             "SELECT name FROM Boss WHERE name = 'Amelia' AND name LIKE 10",
         ),
+        (
+            ValueError::ILikeOnNonString(Value::Str("Amelia".to_string()), Value::I64(10)).into(),
+            "SELECT name FROM Boss WHERE name = 'Amelia' AND name ILIKE 10",
+        ),
     ];
 
     for (error, sql) in error_sqls {
