@@ -1,4 +1,4 @@
-use crate::*;
+use {crate::*, data::ValueError, prelude::Value::*};
 
 test_case!(nullable, async move {
     run!(
@@ -18,8 +18,6 @@ CREATE TABLE Test (
     "
     );
 
-    use Value::*;
-
     let test_cases = vec![
         (
             "SELECT id, num, name FROM Test",
@@ -252,3 +250,23 @@ test_case!(nullable_text, async move {
 
     run!("INSERT INTO Foo (id, name) VALUES (1, \"Hello\"), (2, Null);");
 });
+
+test_case!(nullable_implicit_insert, async move {
+    run!(
+        "
+        CREATE TABLE Foo (
+            id INTEGER,
+            name TEXT NULL
+        );
+    "
+    );
+
+    run!("INSERT INTO Foo (id) VALUES (1)");
+    test!(
+        Ok(select_with_null!(
+            id   | name;
+            I64(1)  Null
+        )),
+        "SELECT id, name FROM Foo"
+    );
+});
