@@ -1,4 +1,4 @@
-use crate::{Value::I64, *};
+use {crate::*, executor::FetchError, prelude::Value::*};
 
 test_case!(create_drop_table, async move {
     // CREATE && ROLLBACK
