@@ -1,17 +1,21 @@
 use {
     super::TranslateError,
     crate::{
-        ast::{AstLiteral, DateTimeField},
+        ast::{AstLiteral, DateTimeField, TrimWhereField},
         result::Result,
     },
-    sqlparser::ast::{DateTimeField as SqlDateTimeField, Value as SqlValue},
+    sqlparser::ast::{
+        DateTimeField as SqlDateTimeField, TrimWhereField as SqlTrimWhereField, Value as SqlValue,
+    },
 };
 
 pub fn translate_ast_literal(sql_value: &SqlValue) -> Result<AstLiteral> {
     Ok(match sql_value {
         SqlValue::Boolean(v) => AstLiteral::Boolean(*v),
         SqlValue::Number(v, _) => AstLiteral::Number(v.clone()),
-        SqlValue::SingleQuotedString(v) => AstLiteral::QuotedString(v.clone()),
+        SqlValue::SingleQuotedString(v) | SqlValue::HexStringLiteral(v) => {
+            AstLiteral::QuotedString(v.clone())
+        }
         SqlValue::Interval {
             value,
             leading_field,
@@ -39,3 +43,12 @@ fn translate_datetime_field(sql_datetime_field: &SqlDateTimeField) -> DateTimeFi
         SqlDateTimeField::Second => DateTimeField::Second,
     }
 }
+
+pub fn translate_trim_where_field(sql_trim_where_field: &SqlTrimWhereField) -> TrimWhereField {
+    use TrimWhereField::*;
+    match sql_trim_where_field {
+        SqlTrimWhereField::Both => Both,
+        SqlTrimWhereField::Leading => Leading,
+        SqlTrimWhereField::Trailing => Trailing,
+    }
+}
