@@ -24,6 +24,7 @@ pub fn translate_binary_operator(
         SqlBinaryOperator::Minus => Ok(BinaryOperator::Minus),
         SqlBinaryOperator::Multiply => Ok(BinaryOperator::Multiply),
         SqlBinaryOperator::Divide => Ok(BinaryOperator::Divide),
+        SqlBinaryOperator::Modulo => Ok(BinaryOperator::Modulo),
         SqlBinaryOperator::StringConcat => Ok(BinaryOperator::StringConcat),
         SqlBinaryOperator::Gt => Ok(BinaryOperator::Gt),
         SqlBinaryOperator::Lt => Ok(BinaryOperator::Lt),
@@ -33,8 +34,11 @@ pub fn translate_binary_operator(
         SqlBinaryOperator::NotEq => Ok(BinaryOperator::NotEq),
         SqlBinaryOperator::And => Ok(BinaryOperator::And),
         SqlBinaryOperator::Or => Ok(BinaryOperator::Or),
+        SqlBinaryOperator::Xor => Ok(BinaryOperator::Xor),
         SqlBinaryOperator::Like => Ok(BinaryOperator::Like),
+        SqlBinaryOperator::ILike => Ok(BinaryOperator::ILike),
         SqlBinaryOperator::NotLike => Ok(BinaryOperator::NotLike),
+        SqlBinaryOperator::NotILike => Ok(BinaryOperator::NotILike),
         _ => Err(TranslateError::UnsupportedBinaryOperator(sql_binary_operator.to_string()).into()),
     }
 }
